@@ -1,5 +1,5 @@
 /* $Id: mystring.h 635 2005-11-02 17:37:50Z bruce $ */
-// Copyright (C) 2016 Bruce Guenter <bruce@untroubled.org>
+// Copyright (C) 2017 Bruce Guenter <bruce@untroubled.org>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -75,6 +75,10 @@ public:
   mystring lower() const;
   mystring upper() const;
 
+  bool starts_with(const mystring&) const;
+  bool starts_with(const char*) const;
+  bool starts_with(const char*, size_t) const;
+
   int find_first(char, size_t = 0) const;
   int find_first_of(const mystring&, size_t = 0) const;
   int find_first_of(const char*, size_t = 0) const;
